.activities-container {
    
    .comment-form {
        margin-bottom: 7px; 
        
        textarea[name="text"] { 
            height: 31px; 
            width: 100%; 
        }
        
        .btn-primary { 
            width: 100%; 
        }
    }
    
    .activities {
        margin-bottom: 0;
        padding-left: 0;
        position: relative;
        
        li {
            list-style: none;
        }
        
        ul {
            padding-left: 0;
        }
        
        .avatar {
            float:left; 
            margin-left: 0;
            max-height: 32px;
            max-width: 32px;
        }
        
        .comment-reply-form {
            
            input[type="text"] { 
                height: 25px; 
                padding: 2px 4px; 
            }
            
            .comment-holder { 
                margin-left: 32px 
            }
            
            .comment-reply-form { 
                margin-bottom: 0 
            }
        }
        
        .comment-reply-form .avatar, .reply .avatar { 
            height: 24px; 
            width: 24px; 
        }
        
        
        .item {
            border-bottom: 1px solid #F2F2F2;
            padding: 10px 0;
            
            .actions { 
                float: right;
                
                .action { 
                    padding: 0 2px;
                }
            }
            
            .msg {
                
                ul li {
                    list-style: disc;
                }
                
                ul, ol { 
                    margin-left: 20px;
                    
                }
            }
            
            .name {
                 
                .about-obj { 
                    color: silver; 
                    margin-left: 5px;
                    
                    a { 
                        color: gray;
                    }
                    
                }
                
            }
            
            .name, .msg, .date, .replies { 
                display: block; 
                margin-left: 40px;
            }
             
        }
        
        .no-activities-found {
            text-align: center;
            margin: 25px 0 5px;
        }
        
        .reply {
            
            .name, .msg, .date { 
                margin-left: 32px; 
            }

        }
        
    }
    
}

.activities-paging { 
    background-color: rgba(255,255,255, .9);
    position: absolute;
    top: 0;
    bottom: 0;
    right: 0;
    left: 0;
    text-align: center;
    padding-top: 25px;
    
    .progress, .progress .bar { 
        display: inline-block; 
        width: 100px; 
    }
}

.activity {
    .actions {
        float: right;
        
        a {
            margin-left: 5px
        }
        
        .date { 
            color: silver; 
        }
        
        .msg {
            
            .field-name, .field-value { 
                font-weight: bold; 
            }
        }
    }
}