{% extends 'activities/base_activity.html' %}
{% load i18n url_tags activity_tags %}
{% block page_title %}Edit Activity Reply - {% endblock %}

{% block breadcrumb %}
    <li>Edit</li>
{% endblock %}

{% block activity_content %}
    <h1>Edit Activity Reply</h1>
    <form method="post" action="{{ request.path }}">
        {% csrf_token %}
        {{ form|render_activity_form }}
        <div class="form-group">
            <div class="col-sm-offset-2 col-sm-10">
                <button type="submit" class="btn btn-primary">Save</button>
                <a href="{{ activity.about.get_absolute_url }}">cancel</a>
            </div>
        </div>
    </form>
{% endblock %}
