{% extends 'activities/base_activity.html' %}
{% load i18n url_tags tz %}
{% block page_title %}Delete Activity Reply - {% endblock %}

{% block breadcrumb %}
    <li>Delete</li>
{% endblock %}

{% block activity_content %}
    <h1>Confirm delete for activity reply</h1>
    {% with user_timezone=user_timezone|default:'UTC' %}
    <dl class="dl-horizontal">
        <dt>Created by</dt>
        <dd>{{ activity_reply.created_user.get_absolute_url_link }}</dd>
        <dt>Created on</dt>
        <dd>{{ activity_reply.created_dttm|timezone:user_timezone|date:'DATETIME_FORMAT' }}</dd>
        <dt>Activity</dt>
        <dd>{{ activity_reply.text|safe }}</dd>
    </dl>
    {% endwith %}
    <form method="post" action="{{ request.path }}">
        {% csrf_token %}
        <div class="form-group">
            <div>
                <button type="submit" class="btn btn-primary">Delete</button>
                <a href="{{ activity.about.get_absolute_url }}">cancel</a>
            </div>
        </div>
    </form>
{% endblock %}
