{% extends ACTIVITIES_BASE_TEMPLATE %}
{% load activity_tags %}
{% block page_title %}Activities - {% endblock %}

{% block activities_content %}
    <h1>Activities</h1>
    {% render_activities page=activities_page obj=activities_about_object activity_url=activity_url %}
{% endblock %}
