{% extends 'activities/base_activity.html' %}
{% load tz %}
{% block page_title %}Activity Reply - {% endblock %}

{% block activity_content %}
    <h1>Activity Reply</h1>
    {% with user_timezone=user_timezone|default:'UTC' %}
    <dl class="dl-horizontal">
        <dt>Created by</dt>
        <dd>{{ activity_reply.created_user.get_absolute_url_link }}</dd>
        <dt>Created on</dt>
        <dd>{{ activity_reply.created_dttm|timezone:user_timezone|date:'DATETIME_FORMAT' }}</dd>
        <dt>Last Modified by</dt>
        <dd>{{ activity_reply.last_modified_user.get_absolute_url_link }}</dd>
        <dt>Last Modified on</dt>
        <dd>{{ activity_reply.last_modified_dttm|timezone:user_timezone|date:'DATETIME_FORMAT' }}</dd>
        <dt>Activity</dt>
        <dd>{{ activity_reply.text|safe }}</dd>
    </dl>
    {% endwith %}
{% endblock %}
